@@ -4,7 +4,7 @@ use warnings; use strict;
 use Mouse;
 use Mouse::Util::TypeConstraints;
 
-our $VERSION = '0.01';
+our $VERSION = '0.02';
 
 use parent 'Elive::DAO::_Base';
 
@@ -14,7 +14,7 @@ use Carp;
 use Try::Tiny;
 use URI;
 
-use Elive::Util;
+use Elive::Util qw{0.01};
 
 BEGIN {
     __PACKAGE__->mk_classdata('_entities' => {});
@@ -27,7 +27,7 @@ BEGIN {
     __PACKAGE__->mk_classdata('_isa');
 };
 
-foreach my $accessor (qw{_object_connection _db_data _deleted _is_copy}) {
+foreach my $accessor (qw{_db_data _deleted _is_copy}) {
     __PACKAGE__->has_metadata($accessor);
 }
 
@@ -478,14 +478,6 @@ instance, or the default connection that will be used.
 
 =cut
 
-sub connection {
-    my $self = shift;
-    my $connection;
-    $connection = $self->_object_connection(@_) if ref $self;
-    $connection ||= $self->_connection(@_);;
-    return $connection;
-}
-
 =head2 disconnect
 
 Disconnects and diassociates an Elluminate connection from this class. It is
